@@ -39,7 +39,7 @@
 //! let b = buf.split();
 //! assert_eq!(b, b"goodbye world"[..]);
 //!
-//! assert_eq!(buf.capacity(), 1030);
+//! assert_eq!(buf.capacity(), 998);
 //! ```
 //!
 //! In the above example, only a single buffer of 1024 is allocated. The handles
@@ -51,7 +51,7 @@
 //! [struct docs]: struct.Bytes.html
 
 #![deny(
-//    warnings,
+    warnings,
 //    missing_docs,
 //    missing_debug_implementations,
     rust_2018_idioms
